FUNCTION apex_modal_page_render (
   p_dynamic_action IN APEX_PLUGIN.T_DYNAMIC_ACTION,
   p_plugin         IN APEX_PLUGIN.T_PLUGIN 
)

   RETURN APEX_PLUGIN.T_DYNAMIC_ACTION_RENDER_RESULT
   
IS

   l_result             APEX_PLUGIN.T_DYNAMIC_ACTION_RENDER_RESULT;
   l_dialog_title       VARCHAR2(4000) := p_dynamic_action.attribute_01;
   l_url_location       VARCHAR2(50) := NVL(p_dynamic_action.attribute_02, 'STATIC');
   l_static_url         VARCHAR2(4000) := p_dynamic_action.attribute_03;
   l_attr_name          VARCHAR2(4000) := NVL(p_dynamic_action.attribute_05, 'data-url');
   l_close_sel          VARCHAR2(4000) := NVL(p_dynamic_action.attribute_06, 'div#success-message');
   l_hw_mode            VARCHAR2(4000) := NVL(p_dynamic_action.attribute_07, 'AUTO');
   l_height             VARCHAR2(4000) := p_dynamic_action.attribute_08;
   l_width              VARCHAR2(4000) := p_dynamic_action.attribute_09;
   l_modal_page_id      VARCHAR2(4000) := p_dynamic_action.attribute_10;
   l_loading_image_type VARCHAR2(30) := NVL(p_plugin.attribute_02, 'DEFAULT');
   l_loading_image_def  VARCHAR2(30) := NVL(p_plugin.attribute_03, 'bar');
   l_loading_image_cust VARCHAR2(32767) := NVL(p_plugin.attribute_04, apex_application.g_image_prefix || 'processing3.gif');
   l_initial_height     NUMBER := NVL(p_plugin.attribute_05, 100);
   l_initial_width      NUMBER := NVL(p_plugin.attribute_06, 100);
   l_effects_speed      NUMBER := 0; --NVL(p_plugin.attribute_0X, 400) had webkit browser issues, replace if/when fixed
   l_loading_image_src  VARCHAR2(32767);
   l_onload_code        VARCHAR2(32767);
   l_crlf               CHAR(2) := CHR(13)||CHR(10);

BEGIN

   IF apex_application.g_debug
   THEN
      apex_plugin_util.debug_dynamic_action(
         p_plugin         => p_plugin,
         p_dynamic_action => p_dynamic_action 
      );
   END IF;
   
   IF l_loading_image_type = 'DEFAULT'
   THEN
      l_loading_image_src := p_plugin.file_prefix || l_loading_image_def || '.gif';
   ELSE
      l_loading_image_src := REPLACE(l_loading_image_cust, '#IMAGE_PREFIX#', apex_application.g_image_prefix);
      l_loading_image_src := REPLACE(l_loading_image_src, '#PLUGIN_PREFIX#', p_plugin.file_prefix);
   END IF;
      
   apex_css.add_file(
      p_name      => 'apex_modal_page',
      p_directory => p_plugin.file_prefix,
      p_version   => NULL
   );

   apex_javascript.add_library(
      p_name      => 'jquery.ui.button',
      p_directory => apex_application.g_image_prefix || 'libraries/jquery-ui/1.8/ui/',
      p_version   => NULL
   );
   
   apex_javascript.add_library(
      p_name      => 'apex_modal_page.min',
      p_directory => p_plugin.file_prefix,
      p_version   => NULL 
   );

   l_onload_code := 'apex.jQuery(document).apex_modal_page({' || l_crlf
      || '   ' || apex_javascript.add_attribute('effectsSpeed',  l_effects_speed) || l_crlf
      || '   ' || apex_javascript.add_attribute('initialHeight',  l_initial_height) || l_crlf
      || '   ' || apex_javascript.add_attribute('initialWidth',  l_initial_width) || l_crlf
      || '   ' || apex_javascript.add_attribute('loadingImageSrc', l_loading_image_src, FALSE, FALSE) || l_crlf
      || '});';
      
   apex_javascript.add_onload_code(
      p_code => l_onload_code
   ); 

   l_result.javascript_function := 
      'function(){' || l_crlf ||
      '   if (this.browserEvent !== ''load''){' || l_crlf ||
      '      apex.jQuery(document).apex_modal_page(''openPageFromApexThis'', this);' || l_crlf ||
      '   }' || l_crlf ||
      '}';

   l_result.attribute_01 := l_dialog_title;
   l_result.attribute_02 := l_url_location;
   l_result.attribute_03 := l_static_url;
   l_result.attribute_05 := l_attr_name;
   l_result.attribute_06 := l_close_sel;
   l_result.attribute_07 := l_hw_mode;
   l_result.attribute_08 := l_height;
   l_result.attribute_09 := l_width;
   l_result.attribute_10 := l_modal_page_id;

   RETURN l_result;
    
END apex_modal_page_render;